@@ -15,6 +15,7 @@
 """Podman transformer module."""
 
 from mrack.transformers.transformer import Transformer
+from mrack.utils import get_host_from_metadata
 
 CONFIG_KEY = "podman"
 
@@ -25,12 +26,28 @@ class PodmanTransformer(Transformer):
     _config_key = CONFIG_KEY
     _required_config_attrs = [
         "images",
+        "pubkey",
+        "default_network",
+        "podman_options",
     ]
 
+    async def init_provider(self):
+        """Initialize associate provider and transformer display name."""
+        self.dsp_name = "Podman"
+
+        await self._provider.init(
+            container_images=self.config["images"].values(),
+            ssh_key=self.config["pubkey"],
+            default_network=self.config["default_network"],
+            container_options=self.config["podman_options"],
+        )
+
     def create_host_requirement(self, host):
         """Create single input for podman provisioner."""
+        _host, domain = get_host_from_metadata(self._metadata, host["name"])
         return {
             "name": host["name"],
             "image": self._get_image(host["os"]),
             "hostname": host["name"],
+            "domain": domain["name"],
         }
