@@ -208,10 +208,10 @@ def get_ssh_key(host, meta_host, config):
 
 def ssh_to_host(
     host,
-    execute=None,
     username=None,
     password=None,
     ssh_key=None,
+    command=None,
 ):
     """SSH to the selected host."""
     my_env = os.environ.copy()
@@ -232,6 +232,7 @@ def ssh_to_host(
     if username:
         cmd.extend(["-l", username])
     if ssh_key:
+        cmd.extend(["-o", "'PasswordAuthentication=no'"])
         cmd.extend(["-i", ssh_key])
     psw_input = None
     if password and not ssh_key:
@@ -240,8 +241,8 @@ def ssh_to_host(
 
     cmd.append(host.ip_addr)  # Destination
 
-    if execute:
-        cmd.extend(["-C", execute])
+    if command:
+        cmd.append(command)
 
     cmd = " ".join(cmd)
 
